==> csbase-common-2.0.1-sources.jar: csbase/logic/algorithms/parsers/InputURLListParameterParser.java <==
package csbase.logic.algorithms.parsers;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;

import csbase.exception.ParseException;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputURLListParameter;
import csbase.logic.algorithms.parameters.ParameterGroup;
import csbase.logic.algorithms.parameters.URLProtocol;
import csbase.logic.algorithms.parameters.URLProtocolConverter;
import csbase.logic.algorithms.parameters.FileURLValue;

/**
 * <p>
 * Analisador de {@link InputURLListParameter}.
 * </p>
 * 
 * <p>
 * Este parser l os atributos de parmetros do tipo "url de entrada" mltiplo.
 * O elemento corrente do {@link XmlParser analisador de XML} precisa ser um
 * elemento {@link InputURLListParameter}.
 * </p>
 * 
 */
public class InputURLListParameterParser extends
  AbstractURLParameterParser<InputURLListParameter> {

  /**
   * {@inheritDoc}
   */
  @Override
  public InputURLListParameter createSimpleParameter(XmlParser parser,
    String name, String label, String description, boolean isOptional,
    boolean isVisible, String commandLinePattern, ParameterGroup group)
    throws ParseException {

    String type = parser.extractAttributeValue(TYPE_ATTRIBUTE, null);
    String localization = parser.extractAttributeValue(LOCALIZATION_ATTRIBUTE);

    String modeName =
      parser.extractAttributeValue(CATEGORY_ATTRIBUTE,
        CATEGORY_VALUE_REGULAR_FILE);

    if (!modeName.equals(CATEGORY_VALUE_DIRECTORY)
      && !modeName.equals(CATEGORY_VALUE_REGULAR_FILE)) {
      throw new ParseException("A categoria informada {0} no  vlida.\n"
        + "Categorias vlidas:\n{1};\n{2}.", modeName,
        CATEGORY_VALUE_REGULAR_FILE, CATEGORY_VALUE_DIRECTORY);
    }

    FileParameterMode mode = FileParameterMode.DIRECTORY;
    if (modeName.equals(CATEGORY_VALUE_REGULAR_FILE)) {
      mode = FileParameterMode.REGULAR_FILE;
    }

    boolean useRootDirectoryAsDefault =
      parser.extractAttributeValueAsBoolean(DEFAULT_DIRECTORY_ATTRIBUTE,
        DEFAULT_DIRECTORY_DEFAULT_VALUE);
    List<FileURLValue> defaultValue = null;
    if (useRootDirectoryAsDefault) {
      if (mode == FileParameterMode.REGULAR_FILE) {
        throw new ParseException(
          "O atributo {0}  invlido quando o parmetro de entrada  um arquivo.",
          DEFAULT_DIRECTORY_ATTRIBUTE);
      }
      defaultValue = new ArrayList<FileURLValue>();
      defaultValue.add(new FileURLValue("."));
    }

    String protocols = parser.extractAttributeValue(PROTOCOLS_ATTRIBUTE, null);
    EnumSet<URLProtocol> allowedProtocols;
    if (protocols != null) {
      allowedProtocols = EnumSet.noneOf(URLProtocol.class);
      String[] protocolsAsArray = protocols.split(",");
      URLProtocolConverter converter = new URLProtocolConverter();
      for (String protocolString : protocolsAsArray) {
        URLProtocol protocol = converter.valueOf(protocolString);
        allowedProtocols.add(protocol);
      }
    }
    else {
      allowedProtocols = EnumSet.allOf(URLProtocol.class);
    }

    boolean mustSort =
      parser.extractAttributeValueAsBoolean(MUST_SORT_ATTRIBUTE,
        MUST_SORT_DEFAULT_VALUE);

    return new InputURLListParameter(name, label, description, defaultValue,
      isOptional, isVisible, commandLinePattern, localization, type, mode,
      mustSort, allowedProtocols);
  }

}

==> csbase-common-2.1.1-sources.jar: csbase/logic/algorithms/parsers/InputURLListParameterParser.java <==
package csbase.logic.algorithms.parsers;

import java.util.Arrays;
import java.util.EnumSet;
import java.util.List;

import csbase.exception.ParseException;
import csbase.logic.algorithms.parameters.FileParameterMode;
import csbase.logic.algorithms.parameters.InputURLListParameter;
import csbase.logic.algorithms.parameters.URLProtocol;
import csbase.logic.algorithms.parameters.FileURLValue;
import csbase.logic.algorithms.parameters.FileParameterPipeAcceptance;

/**
 * <p>
 * Analisador de {@link InputURLListParameter}.
 * </p>
 * 
 * <p>
 * Este parser l os atributos de parmetros do tipo "url de entrada" mltiplo.
 * O elemento corrente do {@link XmlParser analisador de XML} precisa ser um
 * elemento {@link InputURLListParameter}.
 * </p>
 * 
 */
public class InputURLListParameterParser extends
  AbstractURLParameterParser<InputURLListParameter> {

  @Override
  protected InputURLListParameter createURLParameter(XmlParser parser, 
    String name, String label, String description, boolean isOptional,
    boolean isVisible, String commandLinePattern, String type,
    String localization, FileParameterMode mode, FileURLValue defaultValue,
    FileParameterPipeAcceptance usesPipe, EnumSet<URLProtocol> allowedProtocols)
    throws ParseException {

    boolean mustSort =
      parser.extractAttributeValueAsBoolean(MUST_SORT_ATTRIBUTE,
        MUST_SORT_DEFAULT_VALUE);

    List<FileURLValue> defaultValues =
      defaultValue == null ? null : Arrays.asList(defaultValue);
    return new InputURLListParameter(name, label, description, defaultValues,
      isOptional, isVisible, commandLinePattern, localization, type, mode,
      mustSort, allowedProtocols);
  }
}
